@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <QGSettings/QGSettings>
 #include <QDebug>
 #include <QScreen>
+#include <QTimer>
 #include <X11/Xlib.h>
 
 #ifdef __cplusplus
@@ -46,6 +47,9 @@ public:
     void SetBackground();
     void initGSettings();
 
+    void setSolidColorBackground();
+    void draw_background();
+
 private:
     void scaleBg(const QRect &geometry);
     void virtualGeometryChangedProcess(const QRect &geometry);
@@ -54,11 +58,17 @@ public Q_SLOTS:
     void setup_Background(const QString &key);
     void screenAddedProcess(QScreen *screen);
     void screenRemovedProcess(QScreen *screen);
+    void StartXrandrIdleCb();
+
 private:
+    QTimer      *mAcitveTime = nullptr;
     QGSettings  *bSettingOld;
     QScreen     *m_screen;
     QString      Filename;
-    Display     *dpy;
+    Display     *dpy = NULL;
+    Pixmap       pix = NULL;
+    Window       root = NULL;
+    Screen      *scn = NULL;
 };
 
 #endif // BACKGROUND_MANAGER_H
