@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,9 @@
 #include <QString>
 #include <QFile>
 #include <QProcess>
+#include <QDBusInterface>
+#include <QDBusReply>
+#include "usd_base_class.h"
 #include "housekeeping-plugin.h"
 #include "clib-syslog.h"
 
@@ -49,6 +52,10 @@ QString getCurrentUserName()
 
 HousekeepingPlugin::HousekeepingPlugin()
 {
+    if (isInTrialMode()) {
+        USD_LOG(LOG_DEBUG,"TrialMode...");
+        return;
+    }
     userName = getCurrentUserName();
     if (userName.compare("lightdm") != 0) {
         mHouseManager = new HousekeepingManager();
@@ -65,9 +72,9 @@ HousekeepingPlugin::~HousekeepingPlugin()
     }
 }
 
-bool HousekeepingPlugin::isTrialMode()
+bool HousekeepingPlugin::isInTrialMode()
 {
-    QString str;
+    QString str = "";
     QStringList symbList ;
     QFile file("/proc/cmdline");
     if (file.open(QIODevice::ReadOnly)) {
@@ -76,43 +83,51 @@ bool HousekeepingPlugin::isTrialMode()
         symbList = str.split("\r\n");
     }
 
-    if (symbList.indexOf("boot=casper") != -1) {
-        file.close();
+    USD_LOG(LOG_DEBUG,"cmdline:%s",str.toLatin1().data());
+    file.close();
+
+    if (str.contains("boot=casper")) {
         return true;
     }
 
-    file.close();
     if (getuid() == 999)
         return true;
+
     return false;
 }
 
+
+
 void HousekeepingPlugin::activate()
 {
-    if (isTrialMode()) {
-        USD_LOG(LOG_DEBUG,"Housekeeping Manager Not Active");
+    if (isInTrialMode()) {//TrialMode disable this plugin
+        USD_LOG(LOG_DEBUG,"TrialMode...");
         return;
     }
+
     if (userName.compare("lightdm") != 0) {
         USD_LOG(LOG_DEBUG,"Housekeeping Manager Is Start");
-
         mHouseManager->HousekeepingManagerStart();
     }
 }
 
 PluginInterface *HousekeepingPlugin::getInstance()
 {
-    if (nullptr == mInstance)
+    if (nullptr == mInstance) {
         mInstance = new HousekeepingPlugin();
+    }
     return mInstance;
 }
 
 void HousekeepingPlugin::deactivate()
 {
-    //if(isTrialMode())
-    //    return;
-    //if (mHouseManager)
+    if(isInTrialMode()) {
+        return;
+    }
+
+    if (mHouseManager) {
         mHouseManager->HousekeepingManagerStop();
+    }
 }
 
 PluginInterface *createSettingsPlugin()
