@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,23 +18,32 @@
  */
 #include "keybindings-plugin.h"
 #include "clib-syslog.h"
+#include "usd_base_class.h"
 
 PluginInterface    *KeybindingsPlugin::mInstance=nullptr;
-KeybindingsManager *KeybindingsPlugin::mKeyManager=nullptr;
 
 KeybindingsPlugin::KeybindingsPlugin()
 {
     USD_LOG(LOG_DEBUG,"KeybindingsPlugin initializing");
-    if(nullptr == mKeyManager)
-        mKeyManager = KeybindingsManager::KeybindingsManagerNew();
+    if (true) {
+        //wayland
+        m_waylandKeyManager = KeybindingsWaylandManager::KeybindingsWaylandManagerNew();
+    } else {
+        m_xKeyManager = KeybindingsManager::KeybindingsManagerNew();
+    }
 }
 
 KeybindingsPlugin::~KeybindingsPlugin()
 {
     USD_LOG(LOG_DEBUG,"KeybindingsPlugin free");
-    if(mKeyManager){
-        delete mKeyManager;
-        mKeyManager = nullptr;
+    if(m_xKeyManager){
+        delete m_xKeyManager;
+        m_xKeyManager = nullptr;
+    }
+
+    if (m_waylandKeyManager) {
+        delete m_waylandKeyManager;
+        m_waylandKeyManager = nullptr;
     }
 }
 
@@ -42,8 +51,12 @@ void KeybindingsPlugin::activate()
 {
     bool res;
     USD_LOG (LOG_DEBUG, "Activating %s plugin compilation time:[%s] [%s]",MODULE_NAME,__DATE__,__TIME__);
-
-    res = mKeyManager->KeybindingsManagerStart();
+    if (m_xKeyManager) {
+        res = m_xKeyManager->start();
+    }
+    if (m_waylandKeyManager) {
+        m_waylandKeyManager->start();
+    }
     if(!res)
         USD_LOG(LOG_ERR,"Unable to start Keybindings manager");
 }
@@ -57,8 +70,13 @@ PluginInterface *KeybindingsPlugin::getInstance()
 
 void KeybindingsPlugin::deactivate()
 {
+    if (m_xKeyManager) {
+        m_xKeyManager->stop();
+    }
+    if (m_waylandKeyManager) {
+        m_waylandKeyManager->stop();
+    }
     USD_LOG(LOG_DEBUG,"Dectivating Keybindings Plugin");
-    mKeyManager->KeybindingsManagerStop();
 }
 
 PluginInterface *createSettingsPlugin()
