@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #ifndef KEYBOARDPLUGIN_H
 #define KEYBOARDPLUGIN_H
 
+#include "keyboard-wayland-manager.h"
 #include "keyboard-manager.h"
 #include "plugin-interface.h"
 
@@ -36,7 +37,7 @@ private:
     KeyboardPlugin(KeyboardPlugin&)=delete;
 
 private:
-    static KeyboardManager *UsdKeyboardManager;
+    ManagerInterface *KeyboardManager = nullptr;
     static PluginInterface * mInstance;
 
 };
