@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,10 +47,14 @@ KeyboardXkb::KeyboardXkb()
 KeyboardXkb::~KeyboardXkb()
 {
     USD_LOG(LOG_DEBUG,"Keyboard Xkb free");
-    if(settings_desktop)
+    if(settings_desktop) {
         delete settings_desktop;
-    if(settings_kbd)
+        settings_desktop = nullptr;
+    }
+    if(settings_kbd) {
         delete settings_kbd;
+        settings_kbd = nullptr;
+    }
 }
 
 void KeyboardXkb::usd_keyboard_xkb_analyze_sysconfig (void)
@@ -156,7 +160,7 @@ bool KeyboardXkb::filter_xkb_config (void)
 
 static void activation_error (void)
 {
-    Display *dpy = QX11Info::display();
+    Display *dpy = UsdBaseClass::getQx11Info();
     char const *vendor = ServerVendor (dpy);//GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()));
     int release = VendorRelease (dpy);//GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()));
     QMessageBox *dialog;
@@ -180,6 +184,7 @@ static void activation_error (void)
     dialog->show();
     dialog->close();
     delete dialog;
+    dialog = nullptr;
 
 }
 
@@ -255,7 +260,7 @@ void KeyboardXkb::usd_keyboard_xkb_init(KeyboardManager* kbd_manager)
     USD_LOG(LOG_DEBUG,"init --- XKB");
     Display *display;
 
-    display    = QX11Info::display();
+    display    = UsdBaseClass::getQx11Info();
     manager    = kbd_manager;
     xkl_engine = xkl_engine_get_instance (display);
 
@@ -278,7 +283,7 @@ void KeyboardXkb::usd_keyboard_xkb_init(KeyboardManager* kbd_manager)
 
         QObject::connect(settings_kbd,SIGNAL(changed(QString)),this,SLOT(apply_xkb_settings_cb(QString)));
 
-        gdk_window_add_filter (NULL, (GdkFilterFunc)usd_keyboard_xkb_evt_filter, this);
+//        gdk_window_add_filter (NULL, (GdkFilterFunc)usd_keyboard_xkb_evt_filter, this);
 
         if (xkl_engine_get_features (xkl_engine) &XKLF_DEVICE_DISCOVERY)
             g_signal_connect (xkl_engine, "X-new-device",
