@@ -1,7 +1,7 @@
 /* -*- Mode: C++; indent-tabs-mode: nil; tab-width: 4 -*-
  * -*- coding: utf-8 -*-
  *
- * Copyright (C) 2020 KylinSoft Co., Ltd.
+ * Copyright (C) 2023 KylinSoft Co., Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -179,9 +179,11 @@ static double
 get_window_scale (ukuiXSettingsManager *manager)
 {
     GSettings   *gsettings;
-    double       scale;
+    static double  scale = 0;
     gsettings = (GSettings *)g_hash_table_lookup(manager->gsettings,XSETTINGS_PLUGIN_SCHEMA);
-    scale = g_settings_get_double (gsettings, SCALING_FACTOR_KEY);
+    if (scale == 0) {
+        scale = g_settings_get_double (gsettings, SCALING_FACTOR_KEY);
+    }
     /* Auto-detect */
     if (scale == 0)
         scale = get_window_scale_auto ();
@@ -203,7 +205,7 @@ void UkuiXftSettings::xft_settings_set_xsettings (ukuiXSettingsManager *manager)
         manager->pManagers [i]->set_string ("Xft/HintStyle", hintstyle);
 
         manager->pManagers [i]->set_int ( "Gdk/WindowScalingFactor",window_scale);
-        manager->pManagers [i]->set_int ("Gdk/UnscaledDPI",(double)dpi * scale);
+        manager->pManagers [i]->set_int ("Gdk/UnscaledDPI",(double)(dpi * scale));
         manager->pManagers [i]->set_int ("Xft/DPI", scaled_dpi);
 
         manager->pManagers [i]->set_string ("Xft/RGBA", rgba);
@@ -238,20 +240,22 @@ void UkuiXftSettings::xft_settings_get (ukuiXSettingsManager *manager)
     antialias = TRUE;
     this->hinting = TRUE;
     hintstyle = "hintslight";
-    if (scale >= 0 && scale <= 1.5) {
+    if (scale >= 0 && scale <= 1.75) {
           this->window_scale = 1;
-    } else if (scale >= 1.75 && scale <= 2.5) {
+    } else if (scale > 1.75 && scale <= 2.75) {
           this->window_scale = 2;
-    } else if (scale >= 2.75) {
+    } else if (scale > 2.75) {
           this->window_scale = 3;
     }
     this->dpi = dpi * 1024; /* Xft wants 1/1024ths of an inch */
     this->scaled_dpi = dpi * scale * 1024;
 
     cursor_theme = g_settings_get_string (mouse_gsettings, CURSOR_THEME_KEY);
-    cursor_size = g_settings_get_int (mouse_gsettings, CURSOR_SIZE_KEY);
+    cursor_size = g_settings_get_int (mouse_gsettings, CURSOR_SIZE_KEY) * scale;
     rgba = "rgb";
 
+    manager->setKwinMouseSize(cursor_size);
+
     if (rgba_order) {
         int i;
         gboolean found = FALSE;
@@ -338,17 +342,6 @@ void UkuiXftSettings::xft_settings_set_xresources ()
         tmpCursorSize = XcursorGetDefaultSize(dpy);
     }
 
-    QDir dir;
-    QString FilePath = dir.homePath() + "/.xresources";
-    QFile file;
-    QString date = QString("Xcursor.size:%1\n"
-                           "Xcursor.theme:%2").arg(cursor_size).arg(cursor_theme);
-    file.setFileName(FilePath);
-    if(file.open(QIODevice::WriteOnly | QIODevice::Text)){
-        file.write(date.toLatin1().data());
-    }
-    file.close();
-
     update_property (add_string, "Xft.dpi",
             g_ascii_dtostr (dpibuf, sizeof (dpibuf), (double) this->scaled_dpi / 1024.0));
     update_property (add_string, "Xft.antialias",
@@ -389,6 +382,7 @@ void UkuiXftSettings::xft_settings_set_xresources ()
                 "top_left_arrow", "top_left_corner"  , "top_right_corner", "top_side"   ,
                 "top_tee"       , "ul_angle"         , "ur_angle"        , "watch"     ,
                 "xterm"         , "h_double_arrow"   , "v_double_arrow"  , "left_ptr_help",
+                "ibeam", "text",
                 NULL};
 
     if (strlen (tmpCursorTheme) > 0 ) {
